# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ProcessorResponseCode(object):

    """Implementation of the 'Processor Response Code' enum.

    Processor response code for the non-PayPal payment processor errors.

    Attributes:
        ENUM_0000: The enum member of type str.
        ENUM_00N7: The enum member of type str.
        ENUM_0100: The enum member of type str.
        ENUM_0390: The enum member of type str.
        ENUM_0500: The enum member of type str.
        ENUM_0580: The enum member of type str.
        ENUM_0800: The enum member of type str.
        ENUM_0880: The enum member of type str.
        ENUM_0890: The enum member of type str.
        ENUM_0960: The enum member of type str.
        ENUM_0R00: The enum member of type str.
        ENUM_1000: The enum member of type str.
        ENUM_10BR: The enum member of type str.
        ENUM_1300: The enum member of type str.
        ENUM_1310: The enum member of type str.
        ENUM_1312: The enum member of type str.
        ENUM_1317: The enum member of type str.
        ENUM_1320: The enum member of type str.
        ENUM_1330: The enum member of type str.
        ENUM_1335: The enum member of type str.
        ENUM_1340: The enum member of type str.
        ENUM_1350: The enum member of type str.
        ENUM_1352: The enum member of type str.
        ENUM_1360: The enum member of type str.
        ENUM_1370: The enum member of type str.
        ENUM_1380: The enum member of type str.
        ENUM_1382: The enum member of type str.
        ENUM_1384: The enum member of type str.
        ENUM_1390: The enum member of type str.
        ENUM_1393: The enum member of type str.
        ENUM_5100: The enum member of type str.
        ENUM_5110: The enum member of type str.
        ENUM_5120: The enum member of type str.
        ENUM_5130: The enum member of type str.
        ENUM_5135: The enum member of type str.
        ENUM_5140: The enum member of type str.
        ENUM_5150: The enum member of type str.
        ENUM_5160: The enum member of type str.
        ENUM_5170: The enum member of type str.
        ENUM_5180: The enum member of type str.
        ENUM_5190: The enum member of type str.
        ENUM_5200: The enum member of type str.
        ENUM_5210: The enum member of type str.
        ENUM_5400: The enum member of type str.
        ENUM_5500: The enum member of type str.
        ENUM_5650: The enum member of type str.
        ENUM_5700: The enum member of type str.
        ENUM_5710: The enum member of type str.
        ENUM_5800: The enum member of type str.
        ENUM_5900: The enum member of type str.
        ENUM_5910: The enum member of type str.
        ENUM_5920: The enum member of type str.
        ENUM_5930: The enum member of type str.
        ENUM_5950: The enum member of type str.
        ENUM_6300: The enum member of type str.
        ENUM_7600: The enum member of type str.
        ENUM_7700: The enum member of type str.
        ENUM_7710: The enum member of type str.
        ENUM_7800: The enum member of type str.
        ENUM_7900: The enum member of type str.
        ENUM_8000: The enum member of type str.
        ENUM_8010: The enum member of type str.
        ENUM_8020: The enum member of type str.
        ENUM_8030: The enum member of type str.
        ENUM_8100: The enum member of type str.
        ENUM_8110: The enum member of type str.
        ENUM_8220: The enum member of type str.
        ENUM_9100: The enum member of type str.
        ENUM_9500: The enum member of type str.
        ENUM_9510: The enum member of type str.
        ENUM_9520: The enum member of type str.
        ENUM_9530: The enum member of type str.
        ENUM_9540: The enum member of type str.
        ENUM_9600: The enum member of type str.
        PCNR: The enum member of type str.
        PCVV: The enum member of type str.
        PP06: The enum member of type str.
        PPRN: The enum member of type str.
        PPAD: The enum member of type str.
        PPAB: The enum member of type str.
        PPAE: The enum member of type str.
        PPAG: The enum member of type str.
        PPAI: The enum member of type str.
        PPAR: The enum member of type str.
        PPAU: The enum member of type str.
        PPAV: The enum member of type str.
        PPAX: The enum member of type str.
        PPBG: The enum member of type str.
        PPC2: The enum member of type str.
        PPCE: The enum member of type str.
        PPCO: The enum member of type str.
        PPCR: The enum member of type str.
        PPCT: The enum member of type str.
        PPCU: The enum member of type str.
        PPD3: The enum member of type str.
        PPDC: The enum member of type str.
        PPDI: The enum member of type str.
        PPDV: The enum member of type str.
        PPDT: The enum member of type str.
        PPEF: The enum member of type str.
        PPEL: The enum member of type str.
        PPER: The enum member of type str.
        PPEX: The enum member of type str.
        PPFE: The enum member of type str.
        PPFI: The enum member of type str.
        PPFR: The enum member of type str.
        PPFV: The enum member of type str.
        PPGR: The enum member of type str.
        PPH1: The enum member of type str.
        PPIF: The enum member of type str.
        PPII: The enum member of type str.
        PPIM: The enum member of type str.
        PPIT: The enum member of type str.
        PPLR: The enum member of type str.
        PPLS: The enum member of type str.
        PPMB: The enum member of type str.
        PPMC: The enum member of type str.
        PPMD: The enum member of type str.
        PPNC: The enum member of type str.
        PPNL: The enum member of type str.
        PPNM: The enum member of type str.
        PPNT: The enum member of type str.
        PPPH: The enum member of type str.
        PPPI: The enum member of type str.
        PPPM: The enum member of type str.
        PPQC: The enum member of type str.
        PPRE: The enum member of type str.
        PPRF: The enum member of type str.
        PPRR: The enum member of type str.
        PPS0: The enum member of type str.
        PPS1: The enum member of type str.
        PPS2: The enum member of type str.
        PPS3: The enum member of type str.
        PPS4: The enum member of type str.
        PPS5: The enum member of type str.
        PPS6: The enum member of type str.
        PPSC: The enum member of type str.
        PPSD: The enum member of type str.
        PPSE: The enum member of type str.
        PPTE: The enum member of type str.
        PPTF: The enum member of type str.
        PPTI: The enum member of type str.
        PPTR: The enum member of type str.
        PPTT: The enum member of type str.
        PPTV: The enum member of type str.
        PPUA: The enum member of type str.
        PPUC: The enum member of type str.
        PPUE: The enum member of type str.
        PPUI: The enum member of type str.
        PPUP: The enum member of type str.
        PPUR: The enum member of type str.
        PPVC: The enum member of type str.
        PPVE: The enum member of type str.
        PPVT: The enum member of type str.

    """
    ENUM_0000 = '0000'

    ENUM_00N7 = '00N7'

    ENUM_0100 = '0100'

    ENUM_0390 = '0390'

    ENUM_0500 = '0500'

    ENUM_0580 = '0580'

    ENUM_0800 = '0800'

    ENUM_0880 = '0880'

    ENUM_0890 = '0890'

    ENUM_0960 = '0960'

    ENUM_0R00 = '0R00'

    ENUM_1000 = '1000'

    ENUM_10BR = '10BR'

    ENUM_1300 = '1300'

    ENUM_1310 = '1310'

    ENUM_1312 = '1312'

    ENUM_1317 = '1317'

    ENUM_1320 = '1320'

    ENUM_1330 = '1330'

    ENUM_1335 = '1335'

    ENUM_1340 = '1340'

    ENUM_1350 = '1350'

    ENUM_1352 = '1352'

    ENUM_1360 = '1360'

    ENUM_1370 = '1370'

    ENUM_1380 = '1380'

    ENUM_1382 = '1382'

    ENUM_1384 = '1384'

    ENUM_1390 = '1390'

    ENUM_1393 = '1393'

    ENUM_5100 = '5100'

    ENUM_5110 = '5110'

    ENUM_5120 = '5120'

    ENUM_5130 = '5130'

    ENUM_5135 = '5135'

    ENUM_5140 = '5140'

    ENUM_5150 = '5150'

    ENUM_5160 = '5160'

    ENUM_5170 = '5170'

    ENUM_5180 = '5180'

    ENUM_5190 = '5190'

    ENUM_5200 = '5200'

    ENUM_5210 = '5210'

    ENUM_5400 = '5400'

    ENUM_5500 = '5500'

    ENUM_5650 = '5650'

    ENUM_5700 = '5700'

    ENUM_5710 = '5710'

    ENUM_5800 = '5800'

    ENUM_5900 = '5900'

    ENUM_5910 = '5910'

    ENUM_5920 = '5920'

    ENUM_5930 = '5930'

    ENUM_5950 = '5950'

    ENUM_6300 = '6300'

    ENUM_7600 = '7600'

    ENUM_7700 = '7700'

    ENUM_7710 = '7710'

    ENUM_7800 = '7800'

    ENUM_7900 = '7900'

    ENUM_8000 = '8000'

    ENUM_8010 = '8010'

    ENUM_8020 = '8020'

    ENUM_8030 = '8030'

    ENUM_8100 = '8100'

    ENUM_8110 = '8110'

    ENUM_8220 = '8220'

    ENUM_9100 = '9100'

    ENUM_9500 = '9500'

    ENUM_9510 = '9510'

    ENUM_9520 = '9520'

    ENUM_9530 = '9530'

    ENUM_9540 = '9540'

    ENUM_9600 = '9600'

    PCNR = 'PCNR'

    PCVV = 'PCVV'

    PP06 = 'PP06'

    PPRN = 'PPRN'

    PPAD = 'PPAD'

    PPAB = 'PPAB'

    PPAE = 'PPAE'

    PPAG = 'PPAG'

    PPAI = 'PPAI'

    PPAR = 'PPAR'

    PPAU = 'PPAU'

    PPAV = 'PPAV'

    PPAX = 'PPAX'

    PPBG = 'PPBG'

    PPC2 = 'PPC2'

    PPCE = 'PPCE'

    PPCO = 'PPCO'

    PPCR = 'PPCR'

    PPCT = 'PPCT'

    PPCU = 'PPCU'

    PPD3 = 'PPD3'

    PPDC = 'PPDC'

    PPDI = 'PPDI'

    PPDV = 'PPDV'

    PPDT = 'PPDT'

    PPEF = 'PPEF'

    PPEL = 'PPEL'

    PPER = 'PPER'

    PPEX = 'PPEX'

    PPFE = 'PPFE'

    PPFI = 'PPFI'

    PPFR = 'PPFR'

    PPFV = 'PPFV'

    PPGR = 'PPGR'

    PPH1 = 'PPH1'

    PPIF = 'PPIF'

    PPII = 'PPII'

    PPIM = 'PPIM'

    PPIT = 'PPIT'

    PPLR = 'PPLR'

    PPLS = 'PPLS'

    PPMB = 'PPMB'

    PPMC = 'PPMC'

    PPMD = 'PPMD'

    PPNC = 'PPNC'

    PPNL = 'PPNL'

    PPNM = 'PPNM'

    PPNT = 'PPNT'

    PPPH = 'PPPH'

    PPPI = 'PPPI'

    PPPM = 'PPPM'

    PPQC = 'PPQC'

    PPRE = 'PPRE'

    PPRF = 'PPRF'

    PPRR = 'PPRR'

    PPS0 = 'PPS0'

    PPS1 = 'PPS1'

    PPS2 = 'PPS2'

    PPS3 = 'PPS3'

    PPS4 = 'PPS4'

    PPS5 = 'PPS5'

    PPS6 = 'PPS6'

    PPSC = 'PPSC'

    PPSD = 'PPSD'

    PPSE = 'PPSE'

    PPTE = 'PPTE'

    PPTF = 'PPTF'

    PPTI = 'PPTI'

    PPTR = 'PPTR'

    PPTT = 'PPTT'

    PPTV = 'PPTV'

    PPUA = 'PPUA'

    PPUC = 'PPUC'

    PPUE = 'PPUE'

    PPUI = 'PPUI'

    PPUP = 'PPUP'

    PPUR = 'PPUR'

    PPVC = 'PPVC'

    PPVE = 'PPVE'

    PPVT = 'PPVT'

