# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class InstrumentAuthorizationStatus(object):

    """Implementation of the 'Instrument Authorization Status' enum.

    The authorization status of the wallet instrument.

    Attributes:
        AUTHORIZED: The enum member of type str.
        BLOCKED: The enum member of type str.
        FAILED: The enum member of type str.
        NOT_APPLICABLE: The enum member of type str.
        NOT_SUPPORTED: The enum member of type str.
        UNAUTHORIZED: The enum member of type str.

    """
    AUTHORIZED = 'AUTHORIZED'

    BLOCKED = 'BLOCKED'

    FAILED = 'FAILED'

    NOT_APPLICABLE = 'NOT_APPLICABLE'

    NOT_SUPPORTED = 'NOT_SUPPORTED'

    UNAUTHORIZED = 'UNAUTHORIZED'

