# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalPaymentTokenUsagePattern(object):

    """Implementation of the 'PayPal Payment Token Usage Pattern' enum.

    Expected business/pricing model for the billing agreement.

    Attributes:
        IMMEDIATE: The enum member of type str.
        DEFERRED: The enum member of type str.
        RECURRING_PREPAID: The enum member of type str.
        RECURRING_POSTPAID: The enum member of type str.
        THRESHOLD_PREPAID: The enum member of type str.
        THRESHOLD_POSTPAID: The enum member of type str.

    """
    IMMEDIATE = 'IMMEDIATE'

    DEFERRED = 'DEFERRED'

    RECURRING_PREPAID = 'RECURRING_PREPAID'

    RECURRING_POSTPAID = 'RECURRING_POSTPAID'

    THRESHOLD_PREPAID = 'THRESHOLD_PREPAID'

    THRESHOLD_POSTPAID = 'THRESHOLD_POSTPAID'

