# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaymentInitiator(object):

    """Implementation of the 'Payment Initiator' enum.

    The person or party who initiated or triggered the payment.

    Attributes:
        CUSTOMER: The enum member of type str.
        MERCHANT: The enum member of type str.

    """
    CUSTOMER = 'CUSTOMER'

    MERCHANT = 'MERCHANT'

