# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalWalletVaultStatus(object):

    """Implementation of the 'PayPal Wallet Vault Status' enum.

    The vault status.

    Attributes:
        VAULTED: The enum member of type str.
        CREATED: The enum member of type str.
        APPROVED: The enum member of type str.

    """
    VAULTED = 'VAULTED'

    CREATED = 'CREATED'

    APPROVED = 'APPROVED'

