# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PAResStatus(object):

    """Implementation of the 'PARes Status' enum.

    Transactions status result identifier. The outcome of the issuer's
    authentication.

    Attributes:
        Y: The enum member of type str.
        N: The enum member of type str.
        U: The enum member of type str.
        A: The enum member of type str.
        C: The enum member of type str.
        R: The enum member of type str.
        D: The enum member of type str.
        I: The enum member of type str.

    """
    Y = 'Y'

    N = 'N'

    U = 'U'

    A = 'A'

    C = 'C'

    R = 'R'

    D = 'D'

    I = 'I'

