# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalPaymentTokenCustomerType(object):

    """Implementation of the 'PayPal Payment Token Customer Type' enum.

    The customer type associated with the PayPal payment token. This is to
    indicate whether the customer acting on the merchant / platform is either
    a business or a consumer.

    Attributes:
        CONSUMER: The enum member of type str.
        BUSINESS: The enum member of type str.

    """
    CONSUMER = 'CONSUMER'

    BUSINESS = 'BUSINESS'

