# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AuthorizationStatus(object):

    """Implementation of the 'Authorization Status' enum.

    The status for the authorized payment.

    Attributes:
        CREATED: The enum member of type str.
        CAPTURED: The enum member of type str.
        DENIED: The enum member of type str.
        PARTIALLY_CAPTURED: The enum member of type str.
        VOIDED: The enum member of type str.
        PENDING: The enum member of type str.

    """
    CREATED = 'CREATED'

    CAPTURED = 'CAPTURED'

    DENIED = 'DENIED'

    PARTIALLY_CAPTURED = 'PARTIALLY_CAPTURED'

    VOIDED = 'VOIDED'

    PENDING = 'PENDING'

