# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PhoneType(object):

    """Implementation of the 'Phone Type' enum.

    The phone type.

    Attributes:
        FAX: The enum member of type str.
        HOME: The enum member of type str.
        MOBILE: The enum member of type str.
        OTHER: The enum member of type str.
        PAGER: The enum member of type str.

    """
    FAX = 'FAX'

    HOME = 'HOME'

    MOBILE = 'MOBILE'

    OTHER = 'OTHER'

    PAGER = 'PAGER'

