# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CardBrand(object):

    """Implementation of the 'Card Brand' enum.

    The card network or brand. Applies to credit, debit, gift, and payment
    cards.

    Attributes:
        VISA: The enum member of type str.
        MASTERCARD: The enum member of type str.
        DISCOVER: The enum member of type str.
        AMEX: The enum member of type str.
        SOLO: The enum member of type str.
        JCB: The enum member of type str.
        STAR: The enum member of type str.
        DELTA: The enum member of type str.
        SWITCH: The enum member of type str.
        MAESTRO: The enum member of type str.
        CB_NATIONALE: The enum member of type str.
        CONFIGOGA: The enum member of type str.
        CONFIDIS: The enum member of type str.
        ELECTRON: The enum member of type str.
        CETELEM: The enum member of type str.
        CHINA_UNION_PAY: The enum member of type str.
        DINERS: The enum member of type str.
        ELO: The enum member of type str.
        HIPER: The enum member of type str.
        HIPERCARD: The enum member of type str.
        RUPAY: The enum member of type str.
        GE: The enum member of type str.
        SYNCHRONY: The enum member of type str.
        UNKNOWN: The enum member of type str.

    """
    VISA = 'VISA'

    MASTERCARD = 'MASTERCARD'

    DISCOVER = 'DISCOVER'

    AMEX = 'AMEX'

    SOLO = 'SOLO'

    JCB = 'JCB'

    STAR = 'STAR'

    DELTA = 'DELTA'

    SWITCH = 'SWITCH'

    MAESTRO = 'MAESTRO'

    CB_NATIONALE = 'CB_NATIONALE'

    CONFIGOGA = 'CONFIGOGA'

    CONFIDIS = 'CONFIDIS'

    ELECTRON = 'ELECTRON'

    CETELEM = 'CETELEM'

    CHINA_UNION_PAY = 'CHINA_UNION_PAY'

    DINERS = 'DINERS'

    ELO = 'ELO'

    HIPER = 'HIPER'

    HIPERCARD = 'HIPERCARD'

    RUPAY = 'RUPAY'

    GE = 'GE'

    SYNCHRONY = 'SYNCHRONY'

    UNKNOWN = 'UNKNOWN'

