# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper


class ACHDebitResponse(object):

    """Implementation of the 'ACH Debit Response' model.

    A Resource representing a response of vaulted a ACH Debit Account.

    Attributes:
        verification_status (str): The ach debit verification status.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "verification_status": 'verification_status'
    }

    _optionals = [
        'verification_status',
    ]

    def __init__(self,
                 verification_status='NOT_VERIFIED'):
        """Constructor for the ACHDebitResponse class"""

        # Initialize members of the class
        self.verification_status = verification_status 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        verification_status = dictionary.get("verification_status") if dictionary.get("verification_status") else 'NOT_VERIFIED'
        # Return an object of this model
        return cls(verification_status)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'verification_status={(self.verification_status if hasattr(self, "verification_status") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'verification_status={(self.verification_status if hasattr(self, "verification_status") else None)!s})')
