# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalExperienceLandingPage(object):

    """Implementation of the 'PayPal Experience Landing Page' enum.

    The type of landing page to show on the PayPal site for customer checkout.

    Attributes:
        LOGIN: The enum member of type str.
        GUEST_CHECKOUT: The enum member of type str.
        NO_PREFERENCE: The enum member of type str.

    """
    LOGIN = 'LOGIN'

    GUEST_CHECKOUT = 'GUEST_CHECKOUT'

    NO_PREFERENCE = 'NO_PREFERENCE'

